(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{15:function(t,e,n){t.exports=n(23)},23:function(t,e,n){"use strict";n.r(e);var a=n(6),r=n.n(a),c=n(13),o=n.n(c),l=n(0),u=n(1),s=n(2),m=n(3),i=n(11),p=function(t){Object(s.a)(n,t);var e=Object(m.a)(n);function n(t){var a;return Object(u.a)(this,n),(a=e.call(this,t)).render=function(){return r.a.createElement(r.a.Fragment,null)},a._update=function(){var t=localStorage.getItem("__host__");a.setState({hostName:t}),i.a.setComponentValue(t)},a.state={},a._update(),a}return Object(l.a)(n)}(i.b),_=Object(i.c)(p);o.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(_,null)),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.5038c709.chunk.js.map