self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "dfaa7986ef08b72b1daf912659e495fb",
    "url": "./index.html"
  },
  {
    "revision": "c5905921c935395dc05e",
    "url": "./static/css/main.96dbfc01.chunk.css"
  },
  {
    "revision": "15f8e6ac56c0dfc707eb",
    "url": "./static/js/2.fc97ef8c.chunk.js"
  },
  {
    "revision": "3fc7fb5bfeeec1534560a2c962e360a7",
    "url": "./static/js/2.fc97ef8c.chunk.js.LICENSE.txt"
  },
  {
    "revision": "c5905921c935395dc05e",
    "url": "./static/js/main.7570af80.chunk.js"
  },
  {
    "revision": "7c26bca7e16783d14d15",
    "url": "./static/js/runtime-main.11ec9aca.js"
  }
]);