(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{13:function(e,t,n){e.exports={poCheckboxLabel:"style_poCheckboxLabel__2IHB4",poCheckboxSpan:"style_poCheckboxSpan__ltXcy",poCheckbox:"style_poCheckbox__3Q56z"}},18:function(e,t,n){e.exports=n(26)},26:function(e,t,n){"use strict";n.r(t);var o=n(8),a=n.n(o),c=n(16),s=n.n(c),l=n(6),r=n(0),i=n(1),u=n(2),p=n(3),d=n(14),h=n(13),b=n.n(h),k=function(e){Object(u.a)(n,e);var t=Object(p.a)(n);function n(e){var o;Object(i.a)(this,n),(o=t.call(this,e)).render=function(){return a.a.createElement("label",{className:b.a.poCheckboxLabel},a.a.createElement("input",{className:b.a.poCheckbox,type:"checkbox",defaultChecked:o.state.defaultChecked,onChange:o._onChange,disabled:o.props.disabled,onFocus:o._onFocus,onBlur:o._onBlur}),a.a.createElement("span",{className:b.a.poCheckboxSpan},"Sync"))},o._genToken=function(e){var t,n=o.state.delay;console.log(o.state.delay),o.state.isChecked&&(t=n,new Promise((function(n,o){return setTimeout((function(){var t=window.parent.chrome.webview.hostObjects.sync.connection.PassToken(e);n(t)}),t)}))).then((function(e){d.a.setComponentValue(e)}))},o._onChange=function(e){var t=e.target.checked;o.setState({isChecked:t})},o._onFocus=function(){o.setState({isFocused:!0})},o._onBlur=function(){o.setState({isFocused:!1})};var c=o.props.args.defaultChecked,s={defaultChecked:c,isChecked:!!c,delay:o.props.args.delay};return o.state=Object(l.a)({},s),window.parent.genPollinationToken=o._genToken,o}return Object(r.a)(n)}(d.b),_=Object(d.c)(k);s.a.render(a.a.createElement(a.a.StrictMode,null,a.a.createElement(_,null)),document.getElementById("root"))}},[[18,1,2]]]);
//# sourceMappingURL=main.4cdabd50.chunk.js.map